Camera2D class

Available extensions

Constructors

Camera2D({Vector2? offset, Vector2? target, double rotation = 0.0, double zoom = 1.0})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
offset Vector2
getter/setter pair
ptr Pointer<Camera2D>
final
rotation double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Vector2
getter/setter pair
zoom double
getter/setter pair

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
using<R>(R computation(Camera2D)) → R

Available on Camera2D, provided by the Camera2DExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited