RlShaderAttributeDataType enum
Values
- floatType → const RlShaderAttributeDataType
-
const RlShaderAttributeDataType(.RL_SHADER_ATTRIB_FLOAT) - vec2 → const RlShaderAttributeDataType
-
const RlShaderAttributeDataType(.RL_SHADER_ATTRIB_VEC2) - vec3 → const RlShaderAttributeDataType
-
const RlShaderAttributeDataType(.RL_SHADER_ATTRIB_VEC3) - vec4 → const RlShaderAttributeDataType
-
const RlShaderAttributeDataType(.RL_SHADER_ATTRIB_VEC4)
Properties
- code → rlShaderAttributeDataType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlShaderAttributeDataType
Constants
-
values
→ const List<
RlShaderAttributeDataType> - A constant List of the values in this enum, in order of their declaration.