TextureFilter enum

Inheritance
Available extensions

Values

point → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_POINT)
bilinear → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_BILINEAR)
trilinear → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_TRILINEAR)
anisotropic4x → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_ANISOTROPIC_4X)
anisotropic8x → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_ANISOTROPIC_8X)
anisotropic16x → const TextureFilter
const TextureFilter(.TEXTURE_FILTER_ANISOTROPIC_16X)

Properties

code → TextureFilter
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) TextureFilter

Constants

values → const List<TextureFilter>
A constant List of the values in this enum, in order of their declaration.