TextureWrap enum

Inheritance
Available extensions

Values

repeat → const TextureWrap
const TextureWrap(.TEXTURE_WRAP_REPEAT)
clamp → const TextureWrap
const TextureWrap(.TEXTURE_WRAP_CLAMP)
mirrorRepeat → const TextureWrap
const TextureWrap(.TEXTURE_WRAP_MIRROR_REPEAT)
mirrorClamp → const TextureWrap
const TextureWrap(.TEXTURE_WRAP_MIRROR_CLAMP)

Properties

code → TextureWrap
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) TextureWrap

Constants

values → const List<TextureWrap>
A constant List of the values in this enum, in order of their declaration.