rlVertexBuffer class final

Inheritance
Implemented types
Available extensions

Constructors

rlVertexBuffer()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
colors Pointer<UnsignedChar>
getter/setter pair
elementCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indices Pointer<UnsignedInt>
getter/setter pair
normals Pointer<Float>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texcoords Pointer<Float>
getter/setter pair
vaoId int
getter/setter pair
vboId Array<UnsignedInt>
getter/setter pair
vertices Pointer<Float>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited