Camera3D class
- Available extensions
Constructors
Properties
- fovy ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ Vector3
-
getter/setter pair
- projection ↔ CameraProjection
-
getter/setter pair
-
ptr
→ Pointer<
Camera3D> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target ↔ Vector3
-
getter/setter pair
- up ↔ Vector3
-
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
CameraMode mode) → void -
Available on Camera3D, provided by the Camera3DExt extension
-
updatePro(
Vector3 movement, Vector3 rotation, double zoom) → void -
Available on Camera3D, provided by the Camera3DExt extension
-
using<
R> (R computation(Camera3D)) → R -
Available on Camera3D, provided by the Camera3DExt extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited