MouseCursor enum
Values
- default_ → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_DEFAULT) - arrow → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_ARROW) - ibeam → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_IBEAM) - crosshair → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_CROSSHAIR) - pointingHand → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_POINTING_HAND) - resizeEw → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_RESIZE_EW) - resizeNs → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_RESIZE_NS) - resizeNwse → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_RESIZE_NWSE) - resizeNesw → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_RESIZE_NESW) - resizeAll → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_RESIZE_ALL) - notAllowed → const MouseCursor
-
const MouseCursor(.MOUSE_CURSOR_NOT_ALLOWED)
Properties
- code → MouseCursor
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → MouseCursor
Constants
-
values
→ const List<
MouseCursor> - A constant List of the values in this enum, in order of their declaration.