RlTraceLogLevel enum
Values
- all → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_ALL) - trace → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_TRACE) - debug → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_DEBUG) - info → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_INFO) - warning → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_WARNING) - error → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_ERROR) - fatal → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_FATAL) - none → const RlTraceLogLevel
-
const RlTraceLogLevel(.RL_LOG_NONE)
Properties
- code → rlTraceLogLevel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlTraceLogLevel
Constants
-
values
→ const List<
RlTraceLogLevel> - A constant List of the values in this enum, in order of their declaration.