rlgl library

Functions

rlActiveDrawBuffers(int count) → void
rlActiveTextureSlot(int slot) → void
rlBegin(int mode) → void
rlBindFramebuffer(int target, int framebuffer) → void
rlBindImageTexture(int id, int index, int format, bool readonly) → void
rlBindShaderBuffer(int id, int index) → void
rlBlitFramebuffer(int srcX, int srcY, int srcWidth, int srcHeight, int dstX, int dstY, int dstWidth, int dstHeight, int bufferMask) → void
rlCheckErrors() → void
rlCheckRenderBatchLimit(int vCount) bool
rlClearColor(int r, int g, int b, int a) → void
rlClearScreenBuffers() → void
rlColor3f(double x, double y, double z) → void
rlColor4f(double x, double y, double z, double w) → void
rlColor4ub(int r, int g, int b, int a) → void
rlColorMask(bool r, bool g, bool b, bool a) → void
rlComputeShaderDispatch(int groupX, int groupY, int groupZ) → void
rlCopyShaderBuffer(int destId, int srcId, int destOffset, int srcOffset, int count) → void
rlCubemapParameters(int id, int param, int value) → void
rlDisableBackfaceCulling() → void
rlDisableColorBlend() → void
rlDisableDepthMask() → void
rlDisableDepthTest() → void
rlDisableFramebuffer() → void
rlDisableScissorTest() → void
rlDisableShader() → void
rlDisableSmoothLines() → void
rlDisableStereoRender() → void
rlDisableTexture() → void
rlDisableTextureCubemap() → void
rlDisableVertexArray() → void
rlDisableVertexAttribute(int index) → void
rlDisableVertexBuffer() → void
rlDisableVertexBufferElement() → void
rlDisableWireMode() → void
rlDrawRenderBatchActive() → void
rlDrawVertexArray(int offset, int count) → void
rlDrawVertexArrayElements(int offset, int count, Uint8List buffer) → void
rlDrawVertexArrayElementsInstanced(int offset, int count, Uint8List buffer, int instances) → void
rlDrawVertexArrayInstanced(int offset, int count, int instances) → void
rlEnableBackfaceCulling() → void
rlEnableColorBlend() → void
rlEnableDepthMask() → void
rlEnableDepthTest() → void
rlEnableFramebuffer(int id) → void
rlEnablePointMode() → void
rlEnableScissorTest() → void
rlEnableShader(int id) → void
rlEnableSmoothLines() → void
rlEnableStereoRender() → void
rlEnableTexture(int id) → void
rlEnableTextureCubemap(int id) → void
rlEnableVertexArray(int vaoId) bool
rlEnableVertexAttribute(int index) → void
rlEnableVertexBuffer(int id) → void
rlEnableVertexBufferElement(int id) → void
rlEnableWireMode() → void
rlEnd() → void
rlFramebufferAttach(int id, int texId, int attachType, int texType, int mipLevel) → void
rlFramebufferComplete(int id) bool
rlFrustum(double left, double right, double bottom, double top, double znear, double zfar) → void
rlGenTextureMipmaps(int id, int width, int height, int format) int
rlGetActiveFramebuffer() int
rlGetCullDistanceFar() double
rlGetCullDistanceNear() double
rlGetFramebufferHeight() int
rlGetFramebufferWidth() int
rlGetGlTextureFormats(int format) → ({int glFormat, int glInternalFormat, int glType})
rlGetLineWidth() double
rlGetLocationAttrib(int shaderId, String attribName) int
rlGetLocationUniform(int shaderId, String uniformName) int
rlGetMatrixModelview() Matrix4
rlGetMatrixProjection() Matrix4
rlGetMatrixProjectionStereo(int eye) Matrix4
rlGetMatrixTransform() Matrix4
rlGetMatrixViewOffsetStereo(int eye) Matrix4
rlGetPixelFormatName(int format) String
rlGetShaderBufferSize(int id) int
rlGetShaderIdDefault() int
rlGetShaderLocsDefault() Pointer<Int>
rlGetTextureIdDefault() int
rlGetVersion() int
rlglClose() → void
rlglInit(int width, int height) → void
rlIsStereoRenderEnabled() bool
rlLoadDrawCube() → void
rlLoadDrawQuad() → void
rlLoadFramebuffer() int
rlLoadIdentity() → void
rlLoadShaderBuffer(int size, Uint8List? data, int usageHint) int
rlLoadShaderProgram(Pointer<Char> vsCode, Pointer<Char> fsCode) int
rlLoadTexture(Uint8List data, int width, int height, int format, int mipmapCount) int
rlLoadTextureCubemap(Uint8List data, int size, int format, int mipmapCount) int
rlLoadTextureDepth(int width, int height, bool useRenderBuffer) int
rlLoadVertexArray() int
rlLoadVertexBuffer(Uint8List buffer, bool dynamic) int
rlLoadVertexBufferElement(Uint8List buffer, bool dynamic) int
rlMatrixMode(int mode) → void
rlMultMatrixf(Matrix4 mat) → void
rlNormal3f(double x, double y, double z) → void
rlOrtho(double left, double right, double bottom, double top, double znear, double zfar) → void
rlPopMatrix() → void
rlPushMatrix() → void
rlReadScreenPixels(int width, int height) Uint8List
rlReadShaderBuffer(int id, int count, int offset) Uint8List
rlReadTexturePixels(int id, int width, int height, int format) Uint8List
rlRotatef(double angle, double x, double y, double z) → void
rlScalef(double x, double y, double z) → void
rlScissor(int x, int y, int width, int height) → void
rlSetBlendFactors(int glSrcFactor, int glDstFactor, int glEquation) → void
rlSetBlendFactorsSeparate(int glSrcRGB, int glDstRGB, int glSrcAlpha, int glDstAlpha, int glEqRGB, int glEqAlpha) → void
rlSetBlendMode(int mode) → void
rlSetClipPlanes(double nearPlane, double farPlane) → void
rlSetCullFace(int mode) → void
rlSetFramebufferHeight(int height) → void
rlSetFramebufferWidth(int width) → void
rlSetLineWidth(double width) → void
rlSetMatrixModelview(Matrix4 view) → void
rlSetMatrixProjection(Matrix4 proj) → void
rlSetMatrixProjectionStereo(Matrix4 right, Matrix4 left) → void
rlSetMatrixViewOffsetStereo(Matrix4 right, Matrix4 left) → void
rlSetShader(int id, Pointer<Int> locs) → void
rlSetTexture(int id) → void
rlSetUniform(int locIndex, TypedData value, int uniformType, int count) → void
rlSetUniformMatrices(int locIndex, List<Matrix4> mat) → void
rlSetUniformMatrix(int locIndex, Matrix4 mat) → void
rlSetUniformSampler(int locIndex, int textureId) → void
rlSetVertexAttribute(int index, int compSize, int type, bool normalized, int stride, int offset) → void
rlSetVertexAttributeDefault(int locIndex, TypedData value, int attribType, int count) → void
rlSetVertexAttributeDivisor(int index, int divisor) → void
rlTexCoord2f(double x, double y) → void
rlTextureParameters(int id, int param, int value) → void
rlTranslatef(double x, double y, double z) → void
rlUnloadFramebuffer(int id) → void
rlUnloadShaderBuffer(int ssboId) → void
rlUnloadShaderProgram(int id) → void
rlUnloadTexture(int id) → void
rlUnloadVertexArray(int vaoId) → void
rlUnloadVertexBuffer(int vboId) → void
rlUpdateShaderBuffer(int id, Uint8List data, int offset) → void
rlUpdateTexture(int id, int offsetX, int offsetY, int width, int height, int format, Uint8List data) → void
rlUpdateVertexBuffer(int bufferId, Uint8List data, int offset) → void
rlUpdateVertexBufferElements(int id, Uint8List data, int offset) → void
rlVertex2f(double x, double y) → void
rlVertex2i(int x, int y) → void
rlVertex3f(double x, double y, double z) → void
rlViewport(int x, int y, int width, int height) → void